@@ -31,8 +31,8 @@
 
 // This queue is copy pasted from old rust stdlib.
 
-use std::sync::Arc;
 use std::cell::UnsafeCell;
+use std::sync::Arc;
 
 use std::sync::atomic::AtomicUsize;
 use std::sync::atomic::Ordering::{Acquire, Relaxed, Release};
@@ -85,7 +85,7 @@ impl<T: Send> State<T> {
             .collect::<Vec<_>>();
         State {
             pad0: [0; 64],
-            buffer: buffer,
+            buffer,
             mask: capacity - 1,
             pad1: [0; 64],
             enqueue_pos: AtomicUsize::new(0),
@@ -179,9 +179,9 @@ mod bench {
     extern crate test;
     use self::test::Bencher;
 
-    use std::thread;
-    use std::sync::mpsc::channel;
     use super::Queue;
+    use std::sync::mpsc::channel;
+    use std::thread;
 
     #[bench]
     fn bounded_mpmc(b: &mut Bencher) {
